# Wikidata Bib
A helper for building Wikidata-based literature dashboards via SPARQL queries. 

* Free software: MIT license
* Documentation: https://lubianat.github.io/wbib.

# Credits
## Development Lead

-   Tiago Lubiana ([lubianat](https://github.com/lubianat))

## Contributors

-   João Vitor Ferreira Cavalcante ([jvef](https://github.com/jvfe))

## Acknowledgements

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

* [Cookiecutter](https://github.com/audreyr/cookiecutter)
